# Safety_in_Dorm_System
Safety in Dorm System is the project for increase security in the dormitory using OpenCV and Webcam.

This Project use the Python language and OpenCV library to make the Face Recognition using LBPHFace recognizer.

I use Python 2.7.16 , CV2 4.2.0 , numpy 1.16.6

So, If you want to use it in real life you should install and run it on Raspberry Pi or other Single board computer whatever you want.

When you Clone or download this code these necessary step you must do.
  - Install the Python language.
  - Install CV2 and numpy.
  - Delete my Dataset in "datasets" Directory.
  - Run "create_dataset.py" After that, you will see the New directory named "New Person".
  - Rename "New Person" to your name.
  - Run "face_rec_offine.py" to check, if everything no wrong it will make a popup in new window named "Safety in Dorm System".
 
 If you want to send the message to Line via Line Notify FOLLOW these step.
  - Open "face_rec_line.py" with IDLE.
  - Go to line 14, Change the TOKEN to your, you can generate the TOKEN in this website https://notify-bot.line.me/
  - Save and Run "face_rec_line.py".
 
 HAVE FUN, I hope everyone happy with my project, SEE YA!!!
